const wordList = [
    "above", "active", "afraid", "after", "ago", "Alaska", "all", "also", "always", "amazing",
    // ... (rest of the word list from the original code)
    "zoo"
];

let lastLetter = '';
let usedWords = new Set();
let timer;
let timeLeft = 15;

function startTimer() {
    clearInterval(timer);
    timeLeft = 15;
    document.getElementById('timeLeft').textContent = timeLeft;
    timer = setInterval(() => {
        timeLeft--;
        document.getElementById('timeLeft').textContent = timeLeft;
        if (timeLeft <= 0) {
            clearInterval(timer);
            document.getElementById('output').innerHTML = '<p style="color:red;">Time is up! You lose!</p>';
            document.getElementById('inputWord').disabled = true;
        }
    }, 1000);
}

function handleKeyPress(event) {
    if (event.key === 'Enter') {
        playGame();
    }
}

function playGame() {
    const inputWord = document.getElementById('inputWord').value.toLowerCase();
    const outputDiv = document.getElementById('output');

    if (inputWord === '') {
        outputDiv.innerHTML = '<p style="color:red;">Please enter a word.</p>';
        return;
    }

    if (!wordList.includes(inputWord)) {
        outputDiv.innerHTML = `<p style="color:red;">"${inputWord}" is not in the word list. You lose!</p>`;
        clearInterval(timer);
        document.getElementById('inputWord').disabled = true;
        return;
    }

    if (usedWords.has(inputWord)) {
        outputDiv.innerHTML = `<p style="color:red;">"${inputWord}" has already been used. You lose!</p>`;
        clearInterval(timer);
        document.getElementById('inputWord').disabled = true;
        return;
    }

    if (lastLetter !== '' && inputWord[0] !== lastLetter) {
        outputDiv.innerHTML = `<p style="color:red;">"${inputWord}" does not start with "${lastLetter}". You lose!</p>`;
        clearInterval(timer);
        document.getElementById('inputWord').disabled = true;
        return;
    }

    usedWords.add(inputWord);
    lastLetter = inputWord[inputWord.length - 1];

    outputDiv.innerHTML = `<p>You entered: <strong>${inputWord}</strong></p>`;

    const computerWord = findComputerWord(lastLetter);

    if (computerWord === null) {
        outputDiv.innerHTML += '<p style="color:green;">Computer cannot find a word. You win!</p>';
        clearInterval(timer);
        document.getElementById('inputWord').disabled = true;
        return;
    }

    usedWords.add(computerWord);
    lastLetter = computerWord[computerWord.length - 1];

    outputDiv.innerHTML += `<p>Computer responds with: <strong>${computerWord}</strong></p>`;

    document.getElementById('inputWord').value = '';
    startTimer();
}

function findComputerWord(startLetter) {
    const availableWords = wordList.filter(word => 
        word[0] === startLetter && !usedWords.has(word)
    );

    if (availableWords.length === 0) {
        return null;
    }

    return availableWords[Math.floor(Math.random() * availableWords.length)];
}

startTimer();